##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/SharedGitGet)Get Shared Git Credential
Get a shared git credential **Access policy** : Administrator only.
##### Authorizations:
(_ApiKeyAuth_ _jwt_)
### Responses
**201**
Success
**400**
Invalid request payload
**401**
Unauthorized
**403**
Permission denied
**500**
Server error
get/cloud/gitcredentials/{id}
https://api-docs.portainer.io/api/cloud/gitcredentials/{id}
